@@ -1,7 +1,15 @@
 from functools import partial
 import textwrap
+from packaging.version import Version
 
 import pytest
+import numpy as np
+
+
+# Keep this until we require numpy to be >=2.0 or there is a directive in doctestplus
+# to support multiple ways of repr
+if Version(np.__version__) > Version("2.0.0.dev0+151"):
+    np.set_printoptions(legacy="1.25")
 
 
 def _wrap_docstring_in_func(func_name, docstring):
