@@ -1,6 +1,5 @@
 import glob
 import os
-from packaging.version import Version
 from textwrap import dedent
 import sys
 
@@ -676,35 +675,34 @@ def test_ignore_option(testdir):
     ).assertoutcome(passed=2)
 
 
-if Version('4.3.0') <= Version(pytest.__version__):
-    def test_ignore_glob_option(testdir):
-        testdir.makepyfile(foo="""
-            def f():
-                '''
-                >>> 1+1
-                2
-                '''
-                pass
-        """)
-        testdir.makepyfile(bar="""
-            def f():
-                '''
-                >>> 1+1
-                2
-                '''
-                pass
-        """)
-        testdir.makefile('.rst', foo='>>> 1+1\n2')
+def test_ignore_glob_option(testdir):
+    testdir.makepyfile(foo="""
+        def f():
+            '''
+            >>> 1+1
+            2
+            '''
+            pass
+    """)
+    testdir.makepyfile(bar="""
+        def f():
+            '''
+            >>> 1+1
+            2
+            '''
+            pass
+    """)
+    testdir.makefile('.rst', foo='>>> 1+1\n2')
 
-        testdir.inline_run(
-            '--doctest-plus', '--doctest-rst', '--ignore-glob', 'foo*'
-        ).assertoutcome(passed=1)
-        testdir.inline_run(
-            '--doctest-plus', '--doctest-rst', '--ignore-glob', 'bar*'
-        ).assertoutcome(passed=2)
-        testdir.inline_run(
-            '--doctest-plus', '--doctest-rst', '--ignore-glob', '*.rst'
-        ).assertoutcome(passed=2)
+    testdir.inline_run(
+        '--doctest-plus', '--doctest-rst', '--ignore-glob', 'foo*'
+    ).assertoutcome(passed=1)
+    testdir.inline_run(
+        '--doctest-plus', '--doctest-rst', '--ignore-glob', 'bar*'
+    ).assertoutcome(passed=2)
+    testdir.inline_run(
+        '--doctest-plus', '--doctest-rst', '--ignore-glob', '*.rst'
+    ).assertoutcome(passed=2)
 
 
 def test_doctest_only(testdir, makepyfile, maketestfile, makerstfile):
@@ -731,7 +729,7 @@ def test_doctest_only(testdir, makepyfile, maketestfile, makerstfile):
     testdir.inline_run("--doctest-only", "--doctest-rst").assertoutcome(passed=3, failed=2)
 
 
-def test_doctest_float_replacement(tmpdir):
+def test_doctest_float_replacement(tmp_path):
     test1 = dedent("""
         This will demonstrate a doctest that fails due to a few extra decimal
         places::
@@ -748,17 +746,27 @@ def test_doctest_float_replacement(tmpdir):
             0.333333333333333311
     """)
 
-    test1_rst = tmpdir.join('test1.rst')
-    test2_rst = tmpdir.join('test2.rst')
-    test1_rst.write(test1)
-    test2_rst.write(test2)
+    test1_rst = tmp_path / "test1.rst"
+    test2_rst = tmp_path / "test2.rst"
+    test1_rst.write_text(test1)
+    test2_rst.write_text(test2)
 
     with pytest.raises(doctest.DocTestFailure):
-        doctest.testfile(str(test1_rst), module_relative=False,
-                         raise_on_error=True, verbose=False, encoding='utf-8')
+        doctest.testfile(
+            test1_rst,
+            module_relative=False,
+            raise_on_error=True,
+            verbose=False,
+            encoding="utf-8",
+        )
 
-    doctest.testfile(str(test2_rst), module_relative=False,
-                     raise_on_error=True, verbose=False, encoding='utf-8')
+    doctest.testfile(
+        test2_rst,
+        module_relative=False,
+        raise_on_error=True,
+        verbose=False,
+        encoding="utf-8",
+    )
 
 
 def test_doctest_subpackage_requires(testdir, caplog):
@@ -957,6 +965,80 @@ def test_remote_data_ignore_warnings(testdir):
     testdir.inline_run(p, '--doctest-plus', '--doctest-rst').assertoutcome(skipped=1)
 
 
+def test_skiptest(testdir):
+    testdir.makeini(
+        """
+        [pytest]
+        doctestplus = enabled
+    """
+    )
+    p = testdir.makepyfile(
+        """
+        class MyClass:
+            '''
+            >>> import pytest
+            >>> pytest.skip("I changed my mind")
+            >>> assert False, "This should not be reached"
+            '''
+            pass
+    """
+    )
+    reprec = testdir.inline_run(p, "--doctest-plus")
+    reprec.assertoutcome(skipped=1, failed=0)
+
+
+@pytest.mark.parametrize('cont_on_fail', [False, True])
+def test_fail_two_tests(testdir, cont_on_fail):
+    p = testdir.makepyfile(
+        """
+        class MyClass:
+            '''
+            .. doctest::
+
+                >>> print(2)
+                1
+
+            .. doctest::
+
+                >>> print(3)
+                1
+            '''
+            pass
+    """
+    )
+    arg = ("--doctest-continue-on-failure",) if cont_on_fail else ()
+    reprec = testdir.inline_run(p, "--doctest-plus", *arg)
+    reprec.assertoutcome(skipped=0, failed=1)
+    _, _, failed = reprec.listoutcomes()
+    report = failed[0]
+    assert "Expected:\n    1\nGot:\n    2" in report.longreprtext
+    assert ("Expected:\n    1\nGot:\n    3" in report.longreprtext) is cont_on_fail
+
+
+@pytest.mark.parametrize('cont_on_fail', [False, True])
+def test_fail_data_dependency(testdir, cont_on_fail):
+    p = testdir.makepyfile(
+        """
+        class MyClass:
+            '''
+            .. doctest::
+
+                >>> import nonexistentmodule as nem
+                >>> a = nem.calculate_something()
+            '''
+            pass
+    """
+    )
+    arg = ("--doctest-continue-on-failure",) if cont_on_fail else ()
+    reprec = testdir.inline_run(p, "--doctest-plus", *arg)
+    reprec.assertoutcome(skipped=0, failed=1)
+    _, _, failed = reprec.listoutcomes()
+    # Both lines fail in a single error
+    report = failed[0]
+    assert " as nem\nUNEXPECTED EXCEPTION: ModuleNotFoundError" in report.longreprtext
+    assert ("something()\nUNEXPECTED EXCEPTION: NameError" in report.longreprtext) is cont_on_fail
+
+
 def test_ufunc(testdir):
     pytest.importorskip('numpy')
 
@@ -1060,3 +1142,26 @@ def test_ufunc(testdir):
 
     result = testdir.inline_run(build_dir, '--doctest-plus', '--doctest-modules', '--doctest-ufunc')
     result.assertoutcome(passed=2, failed=0)
+
+
+def test_norecursedirs(testdir):
+    testdir.makeini(
+        """
+        [pytest]
+        norecursedirs = \"bad_dir\"
+        doctestplus = enabled
+    """
+    )
+    subdir = testdir.mkdir("bad_dir")
+    badfile = subdir.join("test_foobar.py")
+    badfile.write_text("""
+        def f():
+            '''
+            >>> x = 1/3.
+            >>> x
+            0.333333
+            '''
+            fail
+    """, "utf-8")
+    reprec = testdir.inline_run(str(testdir), "--doctest-plus")
+    reprec.assertoutcome(failed=0, passed=0)
